@@ -137,7 +137,7 @@ ascii_names = ('Lang', 'PlatformLang', 'SbatLevel')
 blist_names = ('BootOrder', 'BootNext')
 dpath_names = ('ConIn', 'ConOut', 'ErrOut')
 
-initial_ts  = datetime.datetime(2010, 1, 1)
+initial_ts  = datetime.datetime(2010, 1, 1, tzinfo = datetime.timezone.utc)
 
 ##################################################################################################
 
@@ -189,7 +189,8 @@ class EfiVar:
         if year:
             self.time = datetime.datetime(year, month, day,
                                           hour, minute, second,
-                                          int(ns / 1000))
+                                          int(ns / 1000),
+                                          tzinfo = datetime.timezone.utc)
         else:
             self.time = None
 
@@ -216,7 +217,7 @@ class EfiVar:
         if not self.attr & EFI_VARIABLE_TIME_BASED_AUTHENTICATED_WRITE_ACCESS:
             return
         if ts is None:
-            ts = datetime.datetime.now()
+            ts = datetime.datetime.now(tz = datetime.timezone.utc)
         if self.time is None or self.time < ts:
             self.time = ts
 
